#include <hidef.h>					// common defines and macros 
#include "derivative.h"				// derivative-specific definitions
#include "sci_hc12.h"				// sci routines

#define LED1	PTT_PTT2
#define LED2	PTT_PTT3
#define LED3	PTT_PTT4
#define LED4	PTT_PTT5

#define SW1		0x10
#define SW2		0x20
#define SW3		0x40
#define SW4		0x80

#define nON		0
#define nOFF	1
#define TOGGLE 1

//#define BLINK	0x1000


/**********************************************************
*	CPMU_PEE_8MHz
*
*	Setup clock module for PLL Engaged using External XTAL
*	For 8MHz XTAL - 
*	VCOCLK - 64MHz, Core Clk - 16MHz, Bus Clk - 8MHz
**********************************************************/
void CPMU_PEE_8MHz(void){

	CPMUSYNR = 0x01;					// fVCO = 32MHz
	CPMUREFDIV = 0x80;				// OSC input is 8MHz
	CPMUPOSTDIV = 0x01;				// core clk - 16MHz, bus clk - 8MHz
	
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC || !CPMUFLG_LOCK);
											// wait for ext osc to stabilize and pll to lock
	CPMUFLG = 0xFF;					// clear CMPMU int flags - not needed but good practice
}


/**********************************************************
*	ATD_EN
*
*	Configure ATD to sample CH0.  Write Channel Select Code
*	bits C[D:A] to start conversion sequence
**********************************************************/
void ATD_EN(void){

	ATDCTL1_SRES = 0;					// 8 bit results
	ATDCTL3_DJM = 1;					// right justified data
	ATDCTL4_PRS = 0;					// bus clk div 2, 4 clks per sample
	ATDSTAT0_SCF = 1;					// clear flag
}


/**********************************************************
*	ACMP_EN
*
*	configure ACMP to read POT.
**********************************************************/
void ACMP_EN(void){

	ACMPC = 0x89;						// en ACMP, falling edge,
											// en ACMP int
	while(!ACMPS_ACIF);				// wait until flag sets
	ACMPS_ACIF = 1;					// clr int flag
}


void main(void) {
	word p = 0;
	byte m[] = "Welcome to Axiom Manufacturing \n";
	byte n[] = "This is the TWR-9S12GN32 Module \n \n";	// welcome message
	DisableInterrupts;				// disable interrupts during setup
	CPMUCOP_CR = 0;					// disable COP
	
	CPMU_PEE_8MHz();					// enable ext osc, 8MHz bus clk

	PTT = 0x3C;							//	init PTT[5:2] to drive LEDs
	DDRT = 0x3C;						//	PTT[5:2] output others input

											// setup PBSW input
	PER1AD = 0xF0;						// enable PBSW pulls
	PPS1AD = 0x00;						// pull-ups applied
	PIE1AD = 0xF0;						// PORTAD[7:4] interrupts enabled
	PIF1AD = 0xF0;						// clr PORTAD int flag
	ATDDIEN = 0x00F0;					// enable PBSW input on PAD[7:4]   

//	PTM = 0x02;							// init PORT M
//	DDRM = 0x03;						// PTM[1:0] output
		
	ensci();								// terminal output @ 19200,8,N,1
	EnableInterrupts;
	cputs(m);							// send welcome message
	cputs(n);							// send welcome message
   
	for(;;){
		
	}
}

#pragma CODE_SEG NON_BANKED

void interrupt 20 sci0_isr(void){
		echo_com();						// echo keybd data
}


void interrupt 25 acmp_isr(void){
	LED1 ^= TOGGLE;
	LED2 ^= TOGGLE;
	LED3 ^= TOGGLE;
	LED4 ^= TOGGLE;				// toggle LEDS on each int
	ACMPS_ACIF = 1;					// clr int flag
}


void interrupt 62 pbsw_isr(void){
	switch(PIF1AD) {				// get switch interrupt status
		case SW1:{					// SW1 pressed
			LED1 ^= TOGGLE;		// toggle LED1
			while((PT1AD & SW1) == 0);	// wait for PBSW release
			PIF1AD &= SW1;			// clr int flag
			break;
		}
		case SW2:{					// SW2 pressed
			LED2 ^= TOGGLE;		// toggle LED2
			while((PT1AD & SW2) == 0);	// wait for PBSW release
			PIF1AD &= SW2;			// clr int flag
			break;
		}
		case SW3:{					// SW1 pressed
			LED3 ^= TOGGLE;		// toggle LED3
			while((PT1AD & SW3) == 0);	// wait for PBSW release
			PIF1AD &= SW3;			// clr int flag
			break;
		}
		case SW4:{					// SW1 pressed
			LED4 ^= TOGGLE;		// toggle LED4
			while((PT1AD & SW4) == 0);	// wait for PBSW release
			PIF1AD &= SW4;			// clr int flag
			break;
		}
		default:
			break;
	}
	
}

#pragma CODE_SEG DEFAULT
